.. _Antiland_ext_commands:

``Antiland.ext.commands`` -- Bot commands framework
====================================================

``Antiland.py`` offers a command extention which makes it easier for users to register commands with set prefixes and avoids the 
need for large amounts of if statements to check which command to run


.. toctree::
    :maxdepth: 2

    commands